METHOD2(".ctor", ctor)
METHOD(CopyTo)
METHOD(Equals)
METHOD(GreaterThan)
METHOD(GreaterThanOrEqual)
METHOD(LessThan)
METHOD(LessThanOrEqual)
METHOD(Min)
METHOD(Max)
METHOD(PopCount)
METHOD(LeadingZeroCount)
METHOD(get_Count)
METHOD(get_IsHardwareAccelerated)
METHOD(get_IsSupported)
METHOD(get_AllOnes)
METHOD(get_Item)
METHOD(get_One)
METHOD(get_Zero)
METHOD(op_Addition)
METHOD(op_BitwiseAnd)
METHOD(op_BitwiseOr)
METHOD(op_Division)
METHOD(op_Equality)
METHOD(op_ExclusiveOr)
METHOD(op_Explicit)
METHOD(op_Inequality)
METHOD(op_Multiply)
METHOD(op_Subtraction)
// Vector
METHOD(ConvertToInt32)
METHOD(ConvertToUInt32)
METHOD(ConvertToInt64)
METHOD(ConvertToUInt64)
METHOD(ConvertToSingle)
METHOD(ConvertToDouble)
METHOD(Narrow)
METHOD(Widen)
// BMI1
METHOD(AndNot)
METHOD(BitFieldExtract)
METHOD(ExtractLowestSetBit)
METHOD(GetMaskUpToLowestSetBit)
METHOD(ResetLowestSetBit)
METHOD(TrailingZeroCount)
// BMI2
METHOD(ZeroHighBits)
METHOD(MultiplyNoFlags)
METHOD(ParallelBitDeposit)
METHOD(ParallelBitExtract)
